@@ -9,7 +9,7 @@
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
- * by the Free Software Foundation, either version 3 of the License, or
+ * by the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
@@ -118,8 +118,6 @@ gd_notification_init (GdNotification *notification)
 
   gtk_widget_set_has_window (GTK_WIDGET (notification), TRUE);
 
-  gtk_widget_push_composite_child ();
-
   priv = notification->priv =
     G_TYPE_INSTANCE_GET_PRIVATE (notification,
                                  GD_TYPE_NOTIFICATION,
@@ -140,8 +138,6 @@ gd_notification_init (GdNotification *notification)
   close_button_image = gtk_image_new_from_icon_name ("window-close-symbolic", GTK_ICON_SIZE_BUTTON);
   gtk_button_set_image (GTK_BUTTON (notification->priv->close_button), close_button_image);
 
-  gtk_widget_pop_composite_child ();
-
   priv->timeout_source_id = 0;
 }
 
