@@ -335,8 +335,6 @@ const PreviewView = new Lang.Class({
             this._onButtonPressEvent));
         this.view.connect('button-release-event', Lang.bind(this,
             this._onButtonReleaseEvent));
-        this.view.connect('key-press-event', Lang.bind(this,
-            this._onKeyPressEvent));
         this.view.connect('selection-changed', Lang.bind(this,
             this._onViewSelectionChanged));
         this.view.connect('external-link', Lang.bind(this,
@@ -389,39 +387,6 @@ const PreviewView = new Lang.Class({
         this._syncControlsVisible();
     },
 
-    _onKeyPressEvent: function(widget, event) {
-        let keyval = event.get_keyval()[1];
-        let state = event.get_state()[1];
-        let def_mod_mask = Gtk.accelerator_get_default_mod_mask();
-
-        if (((keyval == Gdk.KEY_Page_Up) &&
-            ((state & Gdk.ModifierType.CONTROL_MASK) != 0)) ||
-            ((keyval == Gdk.KEY_Left) && ((state & def_mod_mask) == 0))) {
-            this.view.previous_page();
-            return true;
-        }
-
-        if (((keyval == Gdk.KEY_Page_Down) &&
-            ((state & Gdk.ModifierType.CONTROL_MASK) != 0)) ||
-            ((keyval == Gdk.KEY_Right) && ((state & def_mod_mask) == 0))) {
-            this.view.next_page();
-            return true;
-        }
-
-        if (keyval == Gdk.KEY_Page_Up) {
-            this.view.scroll(Gtk.ScrollType.PAGE_BACKWARD, false);
-            return true;
-        }
-
-        if (keyval == Gdk.KEY_space ||
-            keyval == Gdk.KEY_Page_Down) {
-            this.view.scroll(Gtk.ScrollType.PAGE_FORWARD, false);
-            return true;
-        }
-
-        return false;
-     },
-
     _flipControlsTimeout: function() {
         this._controlsFlipId = 0;
         let visible = this.controlsVisible;
@@ -609,7 +574,7 @@ const PreviewNavControls = new Lang.Class({
         let buttonArea = this.bar_widget.get_button_area();
 
         let button = new Gtk.Button({ action_name: 'app.places',
-                                      child: new Gtk.Image({ icon_name: 'view-list-symbolic',
+                                      image: new Gtk.Image({ icon_name: 'view-list-symbolic',
                                                              pixel_size: 16 }),
                                       valign: Gtk.Align.CENTER,
                                       tooltip_text: _("Bookmarks")
@@ -617,14 +582,14 @@ const PreviewNavControls = new Lang.Class({
         buttonArea.pack_start(button, false, false, 0);
 
         button = new Gtk.ToggleButton({ action_name: 'app.bookmark-page',
-                                        child: new Gtk.Image({ icon_name: 'bookmark-add-symbolic',
+                                        image: new Gtk.Image({ icon_name: 'bookmark-add-symbolic',
                                                                pixel_size: 16 }),
                                         valign: Gtk.Align.CENTER,
                                         tooltip_text: _("Bookmark this page")
                                       });
         buttonArea.pack_start(button, false, false, 0);
 
-        this.prev_widget = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'go-previous-symbolic',
+        this.prev_widget = new Gtk.Button({ image: new Gtk.Image ({ icon_name: 'go-previous-symbolic',
                                                                     pixel_size: 16 }),
                                             margin_start: _PREVIEW_NAVBAR_MARGIN,
                                             margin_end: _PREVIEW_NAVBAR_MARGIN,
@@ -636,7 +601,7 @@ const PreviewNavControls = new Lang.Class({
         this.prev_widget.connect('enter-notify-event', Lang.bind(this, this._onEnterNotify));
         this.prev_widget.connect('leave-notify-event', Lang.bind(this, this._onLeaveNotify));
 
-        this.next_widget = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'go-next-symbolic',
+        this.next_widget = new Gtk.Button({ image: new Gtk.Image ({ icon_name: 'go-next-symbolic',
                                                                     pixel_size: 16 }),
                                             margin_start: _PREVIEW_NAVBAR_MARGIN,
                                             margin_end: _PREVIEW_NAVBAR_MARGIN,
@@ -807,9 +772,9 @@ const PreviewToolbar = new Lang.Class({
 
         // menu button, on the right of the toolbar
         let previewMenu = this._getPreviewMenu();
-        let menuButton = new Gd.HeaderMenuButton({ menu_model: previewMenu,
-                                                   action_name: 'app.gear-menu',
-                                                   symbolic_icon_name: 'open-menu-symbolic' });
+        let menuButton = new Gtk.MenuButton({ image: new Gtk.Image ({ icon_name: 'open-menu-symbolic' }),
+                                              menu_model: previewMenu,
+                                              action_name: 'app.gear-menu' });
         this.toolbar.pack_end(menuButton);
 
         // search button, on the right of the toolbar
