@@ -111,7 +111,7 @@ const SearchCategoryManager = new Lang.Class({
     Extends: Manager.BaseManager,
 
     _init: function(context) {
-        this.parent(_("Category"), context);
+        this.parent(_("Category"), 'search-category', context);
 
         let category, recent;
         recent = new SearchCategory({ id: SearchCategoryStock.ALL,
@@ -158,6 +158,15 @@ const SearchType = new Lang.Class({
     }
 });
 
+const SearchTypeStock = {
+    ALL: 'all',
+    COLLECTIONS: 'collections',
+    PDF: 'pdf',
+    PRESENTATIONS: 'presentations',
+    SPREADSHEETS: 'spreadsheets',
+    TEXTDOCS: 'textdocs'
+};
+
 const SearchTypeManager = new Lang.Class({
     Name: 'SearchTypeManager',
     Extends: Manager.BaseManager,
@@ -165,35 +174,35 @@ const SearchTypeManager = new Lang.Class({
     _init: function(context) {
         // Translators: "Type" refers to a search filter on the document type
         // (PDF, spreadsheet, ...)
-        this.parent(C_("Search Filter", "Type"), context);
+        this.parent(C_("Search Filter", "Type"), 'search-type', context);
 
-        this.addItem(new SearchType({ id: 'all',
+        this.addItem(new SearchType({ id: SearchTypeStock.ALL,
                                       name: _("All") }));
-        this.addItem(new SearchType({ id: 'collections',
+        this.addItem(new SearchType({ id: SearchTypeStock.COLLECTIONS,
                                       name: _("Collections"),
                                       filter: 'fn:starts-with(nao:identifier(?urn), \"gd:collection\")',
                                       where: '?urn rdf:type nfo:DataContainer .' }));
-        this.addItem(new SearchType({ id: 'pdf',
+        this.addItem(new SearchType({ id: SearchTypeStock.PDF,
                                       name: _("PDF Documents"),
                                       filter: 'fn:contains(nie:mimeType(?urn), \"application/pdf\")',
                                       where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
-        this.addItem(new SearchType({ id: 'presentations',
+        this.addItem(new SearchType({ id: SearchTypeStock.PRESENTATIONS,
                                       name: _("Presentations"),
                                       where: '?urn rdf:type nfo:Presentation .' }));
-        this.addItem(new SearchType({ id: 'spreadsheets',
+        this.addItem(new SearchType({ id: SearchTypeStock.SPREADSHEETS,
                                       name: _("Spreadsheets"),
                                       where: '?urn rdf:type nfo:Spreadsheet .' }));
-        this.addItem(new SearchType({ id: 'textdocs',
+        this.addItem(new SearchType({ id: SearchTypeStock.TEXTDOCS,
                                       name: _("Text Documents"),
                                       where: '?urn rdf:type nfo:PaginatedTextDocument .' }));
 
-        this.setActiveItemById('all');
+        this.setActiveItemById(SearchTypeStock.ALL);
     },
 
     getCurrentTypes: function() {
         let activeItem = this.getActiveItem();
 
-        if (activeItem.id == 'all')
+        if (activeItem.id == SearchTypeStock.ALL)
             return this.getAllTypes();
 
         return [ activeItem ];
@@ -203,7 +212,7 @@ const SearchTypeManager = new Lang.Class({
         let types = [];
 
         this.forEachItem(function(item) {
-            if (item.id != 'all')
+            if (item.id != SearchTypeStock.ALL)
                 types.push(item);
             });
 
@@ -250,7 +259,7 @@ const SearchMatchManager = new Lang.Class({
     _init: function(context) {
         // Translators: this is a verb that refers to "All", "Title" and "Author",
         // as in "Match All", "Match Title" and "Match Author"
-        this.parent(_("Match"), context);
+        this.parent(_("Match"), 'search-match', context);
 
         this.addItem(new SearchMatch({ id: SearchMatchStock.ALL,
                                        name: _("All") }));
@@ -278,7 +287,7 @@ const SearchMatchManager = new Lang.Class({
     }
 });
 
-const SourceStock = {
+const SearchSourceStock = {
     ALL: 'all',
     LOCAL: 'local'
 };
@@ -378,9 +387,9 @@ const Source = new Lang.Class({
     getFilter: function() {
         let filters = [];
 
-        if (this.id == SourceStock.LOCAL) {
+        if (this.id == SearchSourceStock.LOCAL) {
             filters.push(this._buildFilterLocal());
-        } else if (this.id == SourceStock.ALL) {
+        } else if (this.id == SearchSourceStock.ALL) {
             filters.push(this._buildFilterLocal());
             filters.push(this._manager.getFilterNotLocal());
         } else {
@@ -405,15 +414,15 @@ const SourceManager = new Lang.Class({
     Extends: Manager.BaseManager,
 
     _init: function(context) {
-        this.parent(_("Sources"), context);
+        this.parent(_("Sources"), 'search-source', context);
 
-        let source = new Source({ id: SourceStock.ALL,
+        let source = new Source({ id: SearchSourceStock.ALL,
         // Translators: this refers to documents
                                   name: _("All"),
                                   builtin: true });
         this.addItem(source);
 
-        source = new Source({ id: SourceStock.LOCAL,
+        source = new Source({ id: SearchSourceStock.LOCAL,
         // Translators: this refers to local documents
                               name: _("Local"),
                               builtin: true });
@@ -424,7 +433,7 @@ const SourceManager = new Lang.Class({
         Application.goaClient.connect('account-removed', Lang.bind(this, this._refreshGoaAccounts));
 
         this._refreshGoaAccounts();
-        this.setActiveItemById(SourceStock.ALL);
+        this.setActiveItemById(SearchSourceStock.ALL);
     },
 
     _refreshGoaAccounts: function() {
